@@ -1,13 +1,15 @@
+library(car)
 library(blorr)
 library(caret)
 library(cli)
 library(clisymbols)
+library(crayon)
+library(checkmate)
 library(descriptr)
 library(dplyr)
+library(e1071)
 library(ggplot2)
 library(glue)
-library(grid)
-library(gridExtra)
 library(jsonlite)
 library(lubridate)
 library(magrittr)
@@ -15,6 +17,7 @@ library(purrr)
 library(readr)
 library(readxl)
 library(rlang)
+library(Rcpp)
 library(tidyr)
 library(scales)
 library(shiny)
